/*
 * Pan - A Newsreader for X
 * Copyright (C) 1999  Matt Eagleson (e.Messiah@superpimp.org)
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 * 
 */

#include <stdio.h>
#include <stdlib.h>
#include <ctype.h>
#include <gnome.h>
#include <gtk/gtk.h>
#include <unistd.h>
#include <string.h>
#include <pthread.h>
#include "pan.h"

static GtkWidget *server_menu;
int menu_sensitized = TRUE;

void
server_menu_desensitize(void)
{
	
	menu_sensitized = FALSE;
    pan_lock(); 
	gtk_container_foreach(GTK_CONTAINER(server_menu), (GtkCallback)gtk_widget_set_sensitive, (void *)0);
    pan_unlock(); 
}

void
server_menu_sensitize(void)
{
    menu_sensitized = TRUE;
    pan_lock(); 
    gtk_container_foreach(GTK_CONTAINER(server_menu), (GtkCallback)gtk_widget_set_sensitive, (void *)1);
    pan_unlock(); 
}

void
server_selected_cb (GtkWidget *menuitem, server_data *sdata)
{
    if (sdata == Pan.active_server) {
        return;
    } else {
        Pan.active_server = sdata;
        article_ctree_clean();
        grouplist_free(Pan.grouplist);
        Pan.grouplist = NULL;
        group_clist_update();                    
    }
}                      

void
server_menu_create(GtkWidget *menu)
{
    server_menu = menu;
}

void
server_menu_update()
{
    GtkWidget *menuitem;
    GList *p;
    GSList *group;
    server_data *sdata;

    group = NULL;

    gtk_container_foreach(GTK_CONTAINER(server_menu), (GtkCallback)gtk_widget_destroy, NULL);

    for (p = Pan.props->servers; p ; p = p->next) {
        sdata = p->data;
        menuitem = gtk_radio_menu_item_new_with_label(group, sdata->name);
        group = gtk_radio_menu_item_group (GTK_RADIO_MENU_ITEM(menuitem));
        gtk_check_menu_item_set_show_toggle (GTK_CHECK_MENU_ITEM (menuitem), TRUE);
        gtk_signal_connect(GTK_OBJECT(menuitem), "activate", GTK_SIGNAL_FUNC(server_selected_cb), sdata);
        gtk_widget_show (menuitem);        
        gtk_menu_append (GTK_MENU(server_menu), menuitem);
    }
    if (menu_sensitized == FALSE) {
   	server_menu_desensitize();
    }
}
